@@ -2,9 +2,9 @@ from collections.abc import Mapping
 
 import pytest
 
-from ..source.prompts.prompt_cloze import ClozeWithoutDoc
-from ..source.prompts.prompt_qa import QAWithoutDoc
-from .ankiconnect.anki_converter import AnkiPromptConverter
+from memium.source.document import Document
+
+from ..source.prompt import QAWithDoc
 from .ankiconnect.ankiconnect_gateway import (
     AnkiField,
     ImportPackage,
@@ -19,11 +19,13 @@ from .destination_ankiconnect import AnkiConnectDestination
 @pytest.mark.parametrize(
     ("fields"),
     [
-        ({"Text": AnkiField(value="MockText", order=0)}),
         (
             {
                 "Question": AnkiField(value="MockQuestion", order=0),
                 "Answer": AnkiField(value="MockAnswer", order=1),
+                "raw_question": AnkiField(value="MockQuestion", order=2),
+                "raw_answer": AnkiField(value="MockAnswer", order=3),
+                "Extra": AnkiField(value="MockExtra", order=4),
             }
         ),
         pytest.param(
@@ -32,9 +34,8 @@ from .destination_ankiconnect import AnkiConnectDestination
     ],
 )
 def test_ankiconnect_get_all_prompts(fields: Mapping[str, AnkiField]):
-    dest = AnkiConnectDestination(
-        gateway=SpieAnkiconnectGateway(note_infos=[MockNoteInfo(fields=fields)]),
-        prompt_converter=AnkiPromptConverter(base_deck="FakeDeck", card_css="FakeCSS"),
+    dest = AnkiConnectDestination.dummy(
+        gateway=SpieAnkiconnectGateway(note_infos=[MockNoteInfo(fields=fields)])
     )
     prompts = dest.get_all_prompts()
 
@@ -43,34 +44,30 @@ def test_ankiconnect_get_all_prompts(fields: Mapping[str, AnkiField]):
 
 def test_ankiconnect_push_prompts():
     gateway = SpieAnkiconnectGateway()
-    dest = AnkiConnectDestination(
-        gateway=gateway,
-        prompt_converter=AnkiPromptConverter(base_deck="FakeDeck", card_css="FakeCSS"),
-    )
+    dest = AnkiConnectDestination.dummy(gateway=gateway)
     dest.update(
         [
             PushPrompts(
                 prompts=[
-                    QAWithoutDoc(
+                    QAWithDoc.dummy(
                         question="FakeQuestion",
                         answer="FakeAnswer",
-                        add_tags=["anki/deck/FakeSubdeck/FakeSubSubdeck"],
-                    ),
-                    ClozeWithoutDoc(text="FakeText", add_tags=["FakeTag"]),
+                        parent_doc=Document.dummy(tags=["anki/deck/FakeSubdeck/FakeSubSubdeck"]),
+                    )
                 ]
             )
         ]
     )
 
-    expected_commands = [(ImportPackage, 1), (UpdateModel, 2)]
+    expected_commands = [(ImportPackage, 1), (UpdateModel, 1)]
     import_package_command = next(
         c for c in gateway.executed_commands if isinstance(c, ImportPackage)
     )
     assert (
         import_package_command.package.decks[0].name  # type: ignore
-        == "FakeDeck::FakeSubdeck::FakeSubSubdeck"
+        == "FakeBaseDeck::FakeSubdeck::FakeSubSubdeck"
     )
-    assert len(import_package_command.package.decks) == 2  # type: ignore
+    assert len(import_package_command.package.decks) == 1  # type: ignore
 
     for command in expected_commands:
         assert (
