@@ -3,7 +3,7 @@ from pathlib import Path
 
 import pytest
 
-from memium.core import core
+from memium.__main__ import main
 
 from .destination.ankiconnect.ankiconnect_gateway import anki_connect_is_live
 
@@ -12,7 +12,7 @@ from .destination.ankiconnect.ankiconnect_gateway import anki_connect_is_live
     not anki_connect_is_live() or not Path("/output").exists(),
     reason="Tests require a running AnkiConnect server and an output directory. Use the Docker container to run the tests.",
 )
-def test_main(caplog: pytest.LogCaptureFixture, base_deck: str = "Main Integration Test"):
+def test_main(caplog: pytest.LogCaptureFixture, root_deck: str = "Main Integration Test"):
     caplog.set_level(logging.INFO)
 
     # Clear and delete output path
@@ -32,12 +32,12 @@ A. å
 """
         )
 
-    core(base_deck=base_deck, input_dir=test_input_path, max_deletions_per_run=2, dry_run=False)
+    main(root_deck=root_deck, input_dir=test_input_path, max_deletions_per_run=2, dry_run=False)
     assert "Pushing 1 cards to Anki" in caplog.text
 
     # Test idempotency
-    core(
-        base_deck=base_deck,
+    main(
+        root_deck=root_deck,
         input_dir=test_input_path,
         max_deletions_per_run=0,  # 0 deletions allowed to test idempotency
         dry_run=False,
